@@ -13,11 +13,7 @@ use Chrome::DevToolsProtocol::Transport;
 use Scalar::Util 'weaken', 'isweak';
 
 use vars qw<$VERSION>;
-$VERSION = '0.02';
-
-# DOM access
-# https://chromedevtools.github.io/devtools-protocol/tot/DOM/
-# http://localhost:9222/json
+$VERSION = '0.03';
 
 sub _build_log( $self ) {
     require Log::Log4perl;
@@ -237,10 +233,18 @@ sub one_shot( $self, @events ) {
 };
 
 sub on_response( $self, $connection, $message ) {
-    my $response = $self->json->decode( $message );
+    my $response = eval { $self->json->decode( $message ) };
+    if( $@ ) {
+        $self->log('error', $@ );
+        return;
+    };
 
     if( ! exists $response->{id} ) {
         # Generic message, dispatch that:
+        if( my $error = $response->{error} ) {
+            $self->log('error', "Error response from Chrome", $error );
+            return;
+        };
 
         (my $handler) = grep { exists $_->{events}->{ $response->{method} } and ${$_->{future}} } @{ $self->{one_shot}};
         my $handled;
@@ -297,7 +301,7 @@ sub on_response( $self, $connection, $message ) {
             $self->log( 'debug', "Replying to error $response->{id}", $response );
             $receiver->die( join "\n", $response->{error}->{message},$response->{error}->{data} // '',$response->{error}->{code} // '');
         } else {
-            $self->log( 'debug', "Replying to $response->{id}", $response );
+            $self->log( 'trace', "Replying to $response->{id}", $response );
             $receiver->done( $response->{result} );
         };
     };
@@ -336,14 +340,25 @@ sub _send_packet( $self, $response, $method, %params ) {
         $self->{receivers}->{ $id } = $response;
     };
 
-    my $payload = $self->json->encode({
-        id     => 0+$id,
-        method => $method,
-        params => \%params
-    });
+    my $payload = eval {
+        $self->json->encode({
+            id     => 0+$id,
+            method => $method,
+            params => \%params
+        });
+    };
+    if( my $err = $@ ) {
+        $self->log('error', $@ );
+    };
 
     $self->log( 'trace', "Sent message", $payload );
-    $self->transport->send( $payload );
+    my $result = eval {
+        $self->transport->send( $payload );
+    };
+    if( my $err = $@ ) {
+        $self->log('error', $@ );
+    };
+    $result
 }
 
 =head2 C<< $chrome->send_packet >>
