@@ -12,7 +12,7 @@ use AnyEvent::WebSocket::Client;
 use AnyEvent::Future qw(as_future_cb);
 
 use vars qw<$VERSION $magic @CARP_NOT>;
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,9 @@ sub connect( $self, $handler, $got_endpoint, $logger ) {
 
         my $res = as_future_cb( sub( $done_cb, $fail_cb ) {
             $logger->('debug',"Connecting to $endpoint");
-            $client = AnyEvent::WebSocket::Client->new;
+            $client = AnyEvent::WebSocket::Client->new(
+                max_payload_size => undef, # allow unlimited size for messages
+            );
             $client->connect( $endpoint )->cb( $done_cb );
         });
         $res
@@ -56,6 +58,7 @@ sub connect( $self, $handler, $got_endpoint, $logger ) {
     })->then( sub( $c ) {
         $logger->( 'trace', sprintf "Connected" );
         my $connection = $c->recv;
+
         $self->{connection} = $connection;
         undef $self;
 
@@ -63,6 +66,9 @@ sub connect( $self, $handler, $got_endpoint, $logger ) {
         $connection->on( each_message => sub( $connection,$message) {
             $handler->on_response( $connection, $message->body )
         });
+        $connection->on( parse_error => sub( $connection, $error) {
+            $logger->('error', $error);
+        });
 
         my $res = Future->done( $self );
         undef $self;
